@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef EWSCREATEFOLDERREQUEST_H
-#define EWSCREATEFOLDERREQUEST_H
+#pragma once
 
 #include <QList>
 #include <QSharedPointer>
@@ -66,4 +65,3 @@ private:
     QList<Response> mResponses;
 };
 
-#endif
