@@ -9,12 +9,12 @@
 #include "filestore/entitycompactchangeattribute.h"
 #include "mixedmaildirresource_debug.h"
 
-#include <AkonadiCore/collection.h>
-#include <AkonadiCore/collectionmodifyjob.h>
-#include <AkonadiCore/item.h>
-#include <AkonadiCore/itemfetchjob.h>
-#include <AkonadiCore/itemmodifyjob.h>
-#include <AkonadiCore/session.h>
+#include <Akonadi/Collection>
+#include <Akonadi/CollectionModifyJob>
+#include <Akonadi/Item>
+#include <Akonadi/ItemFetchJob>
+#include <Akonadi/ItemModifyJob>
+#include <Akonadi/Session>
 
 #include <QMap>
 #include <QQueue>
@@ -30,12 +30,12 @@ struct UpdateBatch {
     Collection collection;
 };
 
-class CompactChangeHelper::Private
+class CompactChangeHelperPrivate
 {
     CompactChangeHelper *const q;
 
 public:
-    explicit Private(CompactChangeHelper *parent)
+    explicit CompactChangeHelperPrivate(CompactChangeHelper *parent)
         : q(parent)
     {
     }
@@ -52,7 +52,7 @@ public: // slots
     void itemFetchResult(KJob *job);
 };
 
-void CompactChangeHelper::Private::processNextBatch()
+void CompactChangeHelperPrivate::processNextBatch()
 {
     // qCDebug(MIXEDMAILDIRRESOURCE_LOG) << "pendingUpdates.count=" << mPendingUpdates.count();
     if (mPendingUpdates.isEmpty()) {
@@ -64,7 +64,7 @@ void CompactChangeHelper::Private::processNextBatch()
     processNextItem();
 }
 
-void CompactChangeHelper::Private::processNextItem()
+void CompactChangeHelperPrivate::processNextItem()
 {
     // qCDebug(MIXEDMAILDIRRESOURCE_LOG) << "mCurrentUpdate.items.count=" << mCurrentUpdate.items.count();
     if (mCurrentUpdate.items.isEmpty()) {
@@ -88,7 +88,7 @@ void CompactChangeHelper::Private::processNextItem()
     });
 }
 
-void CompactChangeHelper::Private::itemFetchResult(KJob *job)
+void CompactChangeHelperPrivate::itemFetchResult(KJob *job)
 {
     auto fetchJob = qobject_cast<ItemFetchJob *>(job);
     Q_ASSERT(fetchJob != nullptr);
@@ -126,15 +126,12 @@ void CompactChangeHelper::Private::itemFetchResult(KJob *job)
 
 CompactChangeHelper::CompactChangeHelper(const QByteArray &sessionId, QObject *parent)
     : QObject(parent)
-    , d(new Private(this))
+    , d(new CompactChangeHelperPrivate(this))
 {
     d->mSession = new Session(sessionId, this);
 }
 
-CompactChangeHelper::~CompactChangeHelper()
-{
-    delete d;
-}
+CompactChangeHelper::~CompactChangeHelper() = default;
 
 void CompactChangeHelper::addChangedItems(const Item::List &items)
 {
