@@ -6,7 +6,11 @@
 
 #include "settings.h"
 #include "settingsadaptor.h"
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <qt5keychain/keychain.h>
+#else
+#include <qt6keychain/keychain.h>
+#endif
 using namespace QKeychain;
 #include "pop3resource_debug.h"
 
